document.addEventListener("DOMContentLoaded", function() {
    // DOMContentLoaded event listener function
    
    document.getElementById("urlForm").addEventListener("submit", function(event) {
        event.preventDefault();

        // Validate entered URL
        const inputURL = document.getElementById("inputURL").value.trim();
        var valid = validateURL(inputURL);
        if(!valid) {
            return;
        }
        
        // Send URL to the PHP endpoint to create a short URL 
        const errorContainer = document.getElementById("error");
        const shortenedURLContainer = document.getElementById("shortenedURL");
        var shortCodeInput = Math.floor(Math.random() * 10000);
        errorContainer.textContent = "";
        errorContainer.style.display = "none";
        shortenedURLContainer.textContent = "";
        showLoader();
        fetch("url_shorterner_endpoint.php", {
            method: "POST",
            headers: {
                "Content-Type": "application/json"
            },
            body: JSON.stringify({ url: inputURL, shortCodeInput: shortCodeInput})
        })
        .then(response => response.json())
        .then(data => {
            if (data.shortCode) {
                const shortenedURL = window.location.href + data.shortCode;
                shortenedURLContainer.innerHTML = `<a href="${shortenedURL}" target="_blank">${shortenedURL}</a>`;
            } else {
                // Error returned from the PHP API endpoint 
                // if unable to create a short URL
                errorContainer.textContent = "Problem in creating short URL.";
                errorContainer.style.display = "block"; 
            }
        })
        .catch(error => {
            // Error if unable to access the PHP API endpoint
            errorContainer.textContent = "Problem in creating short URL.";
            errorContainer.style.display = "block"; 
        })
        .finally(() => {
            hideLoader();
        });
    });

    function showLoader() {
        // Show loading indicator here
        document.getElementById("loadingIndicator").style.display = "block";
        // Hide the "Create Short URL" button while loading
        document.querySelector("#urlForm button").style.display = "none";
    }

    function hideLoader() {
        // Hide loading indicator here
        document.getElementById("loadingIndicator").style.display = "none";
        // Show the "Create Short URL" button after loading
        document.querySelector("#urlForm button").style.display = "block";
    }

    function validateURL(inputURL) {
        valid = true;
        const urlRegex = /^(ftp|http|https):\/\/[^ "]+$/;
        if (inputURL === "") {
            document.querySelector(".validation-message").textContent = "URL is required.";
            valid = false;
        } else if (!urlRegex.test(inputURL)) {
            document.querySelector(".validation-message").textContent = "Please enter a valid URL.";
            valid = false;
        }
        return valid;
    }
});
